@@ -192,7 +192,6 @@ class ResponsesMockServer(BaseTestServer):
 
     async def _find_response(self, request):
         for i, (route, response) in enumerate(self._responses):
-
             if not await route.matches(request):
                 continue
 
@@ -332,6 +331,7 @@ class ResponsesMockServer(BaseTestServer):
 
 
 @asyncio_fixture()
-async def aresponses(event_loop) -> ResponsesMockServer:
-    async with ResponsesMockServer(loop=event_loop) as server:
+async def aresponses() -> ResponsesMockServer:
+    loop = asyncio.get_running_loop()
+    async with ResponsesMockServer(loop=loop) as server:
         yield server
